pub struct BundleExtensionIndices { /* private fields */ }Expand description
Auto-generated bindings for index of the exports of
bundle-extension.
This is an implementation detail of BundleExtensionPre and can
be constructed if needed as well.
For more information see BundleExtension as well.
Implementations
Sourceimpl BundleExtensionIndices
impl BundleExtensionIndices
Sourcepub fn new<_T>(_instance_pre: &InstancePre<_T>) -> Result<Self>
pub fn new<_T>(_instance_pre: &InstancePre<_T>) -> Result<Self>
Creates a new copy of BundleExtensionIndices bindings which can then
be used to instantiate into a particular store.
This method may fail if the component does not have the required exports.
Sourcepub fn load(
&self,
store: impl AsContextMut,
instance: &Instance,
) -> Result<BundleExtension>
pub fn load( &self, store: impl AsContextMut, instance: &Instance, ) -> Result<BundleExtension>
Uses the indices stored in self to load an instance
of BundleExtension from the instance provided.
Note that at this time this method will additionally perform type-checks of all exports.