pub struct DeployExtension { /* private fields */ }Expand description
Auto-generated bindings for an instance a component which
implements the world deploy-extension.
This structure can be created through a number of means depending on your requirements and what you have on hand:
-
The most convenient way is to use
DeployExtension::instantiatewhich only needs aStore,Component, andLinker. -
Alternatively you can create a
DeployExtensionPreahead of time with aComponentto front-load string lookups of exports once instead of per-instantiation. This method then usesDeployExtensionPre::instantiateto create aDeployExtension. -
If you’ve instantiated the instance yourself already then you can use
DeployExtension::new.
These methods are all equivalent to one another and move around the tradeoff of what work is performed when.
Implementations
Sourceimpl DeployExtension
impl DeployExtension
Sourcepub fn instantiate<_T>(
store: impl AsContextMut<Data = _T>,
component: &Component,
linker: &Linker<_T>,
) -> Result<DeployExtension>
pub fn instantiate<_T>( store: impl AsContextMut<Data = _T>, component: &Component, linker: &Linker<_T>, ) -> Result<DeployExtension>
Convenience wrapper around DeployExtensionPre::new and
DeployExtensionPre::instantiate.
Sourcepub fn new(
store: impl AsContextMut,
instance: &Instance,
) -> Result<DeployExtension>
pub fn new( store: impl AsContextMut, instance: &Instance, ) -> Result<DeployExtension>
Convenience wrapper around DeployExtensionIndices::new and
DeployExtensionIndices::load.
Sourcepub async fn instantiate_async<_T>(
store: impl AsContextMut<Data = _T>,
component: &Component,
linker: &Linker<_T>,
) -> Result<DeployExtension>where
_T: Send,
pub async fn instantiate_async<_T>(
store: impl AsContextMut<Data = _T>,
component: &Component,
linker: &Linker<_T>,
) -> Result<DeployExtension>where
_T: Send,
Convenience wrapper around DeployExtensionPre::new and
DeployExtensionPre::instantiate_async.
pub fn add_to_linker<T, D>(
linker: &mut Linker<T>,
host_getter: fn(&mut T) -> D::Data<'_>,
) -> Result<()>where
D: HostWithStore + HostWithStore + HostWithStore + HostWithStore + HostWithStore,
for<'a> D::Data<'a>: Host + Host + Host + Host + Host,
T: 'static,
pub fn greentic_extension_base0_2_0_manifest(&self) -> &Guest
pub fn greentic_extension_base0_2_0_lifecycle(&self) -> &Guest
pub fn greentic_extension_deploy0_2_0_targets(&self) -> &Guest
pub fn greentic_extension_deploy0_2_0_deployment(&self) -> &Guest