pub struct DesignExtension { /* private fields */ }Expand description
Auto-generated bindings for an instance a component which
implements the world design-extension.
This structure can be created through a number of means depending on your requirements and what you have on hand:
-
The most convenient way is to use
DesignExtension::instantiatewhich only needs aStore,Component, andLinker. -
Alternatively you can create a
DesignExtensionPreahead of time with aComponentto front-load string lookups of exports once instead of per-instantiation. This method then usesDesignExtensionPre::instantiateto create aDesignExtension. -
If you’ve instantiated the instance yourself already then you can use
DesignExtension::new.
These methods are all equivalent to one another and move around the tradeoff of what work is performed when.
Implementations
Sourceimpl DesignExtension
impl DesignExtension
Sourcepub fn instantiate<_T>(
store: impl AsContextMut<Data = _T>,
component: &Component,
linker: &Linker<_T>,
) -> Result<DesignExtension>
pub fn instantiate<_T>( store: impl AsContextMut<Data = _T>, component: &Component, linker: &Linker<_T>, ) -> Result<DesignExtension>
Convenience wrapper around DesignExtensionPre::new and
DesignExtensionPre::instantiate.
Sourcepub fn new(
store: impl AsContextMut,
instance: &Instance,
) -> Result<DesignExtension>
pub fn new( store: impl AsContextMut, instance: &Instance, ) -> Result<DesignExtension>
Convenience wrapper around DesignExtensionIndices::new and
DesignExtensionIndices::load.
Sourcepub async fn instantiate_async<_T>(
store: impl AsContextMut<Data = _T>,
component: &Component,
linker: &Linker<_T>,
) -> Result<DesignExtension>where
_T: Send,
pub async fn instantiate_async<_T>(
store: impl AsContextMut<Data = _T>,
component: &Component,
linker: &Linker<_T>,
) -> Result<DesignExtension>where
_T: Send,
Convenience wrapper around DesignExtensionPre::new and
DesignExtensionPre::instantiate_async.
pub fn add_to_linker<T, D>(
linker: &mut Linker<T>,
host_getter: fn(&mut T) -> D::Data<'_>,
) -> Result<()>where
D: HostWithStore + HostWithStore + HostWithStore + HostWithStore + HostWithStore + HostWithStore + HostWithStore,
for<'a> D::Data<'a>: Host + Host + Host + Host + Host + Host + Host,
T: 'static,
pub fn greentic_extension_base0_1_0_manifest(&self) -> &Guest
pub fn greentic_extension_base0_1_0_lifecycle(&self) -> &Guest
pub fn greentic_extension_design0_2_0_tools(&self) -> &Guest
pub fn greentic_extension_design0_2_0_validation(&self) -> &Guest
pub fn greentic_extension_design0_2_0_prompting(&self) -> &Guest
pub fn greentic_extension_design0_2_0_knowledge(&self) -> &Guest
pub fn greentic_extension_design0_2_0_roles(&self) -> &Guest